@@ -75,10 +75,10 @@ namespace Oxygen
         {}
 
         //! configure
-        virtual void initializeConfigurationWidget( QWidget* );
+        void initializeConfigurationWidget( QWidget* ) ;
 
         //! configuration widget
-        virtual QWidget* configurationWidget( void ) const
+        QWidget* configurationWidget( void ) const
         {
             Q_CHECK_PTR( _configurationWidget );
             return _configurationWidget.data();
